News
====

Lists of changes between versions.

1.0.0
-----
* Minor: Support Python 3.13.
* Minor: Use cli from bouillon instead of boil.py.
* Minor: Use brundle to run linters.

0.3.0
-----
* Initial release #2

0.2.0
------
* Initial release
